#ifndef BUILD_CONFIG_H
#define BUILD_CONFIG_H

//------------------------------------------------------------
// Purpose:
//     Define your source root and build root from CMake vars
//     so you can pass paths from CMake into C++
//------------------------------------------------------------
// Notes:
//     If you need these CMake variables for pure C code,
//     then use the #define variables, otherwise, use the
//     get methods defined in the gnsstk namespace.
//------------------------------------------------------------

#include <string>

namespace gnsstk
{

  //----------------------------------------
  // Purpose: get path separator character, e.g. ":" or ";"
  // Usage:   std::string file_sep = gnsstk::getPathSep()
  //----------------------------------------
  inline std::string getPathSep( void )
  {
    #ifdef WIN32
    const std::string path_sep(";");
    #else
    const std::string path_sep(":");
    #endif

    return( path_sep );
  }

  //----------------------------------------
  // Purpose: get file system file separator character, e.g. "/" or "\"
  // Usage:   std::string file_sep = gnsstk::getFileSep()
  //----------------------------------------
  inline std::string getFileSep( void )
  {
    #ifdef WIN32
    const std::string file_sep("\\");
    #else
    const std::string file_sep("/");
    #endif
    return( file_sep );
  }

  //----------------------------------------
  // Purpose: get file system path to top level of source tree
  // Usage:   std::string src_path = gnsstk::getPathSrc()
  //----------------------------------------
  inline std::string getPathSrc( void )
  {
    return( "/home/abuild/rpmbuild/BUILD/gnsstk-14.3.0" );
  }

  //----------------------------------------
  // Purpose: get file system path to the CMake build dir
  // Usage:   std::string build_path = gnsstk::getPathBuild()
  //----------------------------------------
  inline std::string getPathBuild( void )
  {
    return( "/home/abuild/rpmbuild/BUILD/gnsstk-14.3.0/build" );
  }

  //----------------------------------------
  // Purpose: get file system path to location of gnsstk data files
  // Usage:   std::string data_path = gnsstk::getPathData()
  //----------------------------------------
  inline std::string getPathData( void )
  {
    return( "/home/abuild/rpmbuild/BUILD/gnsstk-14.3.0/data" );
  }

  //----------------------------------------
  // Purpose: get file system path to location to write temp test output
  // Usage:   std::string temp_path = gnsstk::getPathTestTemp()
  //----------------------------------------
  inline std::string getPathTestTemp( void )
  {
     return( "/home/abuild/rpmbuild/BUILD/gnsstk-14.3.0/build/Testing/Temporary" );
  }


}

#endif // BUILD_CONFIG_H

